@@ -34,7 +34,7 @@
 unique.stlpp <- function(x,...){
   if (!inherits(x, "stlpp")) stop("X should be from class stlpp")
 
-  Y <- unique(as.data.frame(x$data),...)
-  X <- as.stlpp(Y$x,Y$y,Y$t,L=domain(x))
+  id <- which(duplicated(as.data.frame(X$data)))
+  X <- X[-id]
   return(X)
 }
